var EddCmCondition = (function EddCmConditionClass(_super) {

	// Inheritance
	EddCmCondition.prototype = Object.create(_super.prototype);

	/**
	 * jQuery alias.
	 * 
	 * @type {jQuery}
	 */
	var $ = jQuery;

	/**
	 * Default property values.
	 * 
	 * @type {Object}
	 */
	var _defaults = {
		condition: '',
		negation: false,
		fieldData: {}
	};

	/**
	 * Class for a single message.
	 */
	function EddCmCondition( condition, negation, fieldData, conditions, state ) {
		// Set property values
		this.condition = (typeof condition === 'string')? condition : _defaults.condition;
		this.negation = (typeof negation === 'boolean')? negation : _defaults.negation;
		this.fieldData = (typeof fieldData === 'object')? fieldData : _defaults.fieldData;
		// Super constructor
		_super.apply(this, [conditions, state]);
	}

	/**
	 * Initializes the element.
	 */
	EddCmCondition.prototype.initElem = function() {
		// call super method
		_super.prototype.initElem.apply(this, []);
		// Add condition type to conditional element
		this.elem.addClass('condition');
		// Clone template
		var content = $('#edd-cm-condition-template').clone(true, true).children();
        // Get loading template pointer
        this.loadingTemplate = $('#edd-cm-condition-fields-loading-template');
		// Put cloned template into content element
		this.contentContainer.append(content);
		// Save pointer to the select element
		this.selectElem = this.contentContainer.find('> select.condition');
		// Save pointer to the fields container
		this.fieldsContainer = this.contentContainer.find('> div.fields');
		// Save pointer to negate button
		this.negateButton = this.contentContainer.find('button.condition-negate-button');
		// Set condition to select element
		this.selectElem.val(this.condition);

		// Negate if necessary
		if (this.negation) this.negate();
	};

	/**
	 * Initializes element events.
	 */
	EddCmCondition.prototype.initEvents = function() {
		// Super method
		_super.prototype.initEvents.apply(this, []);
		// Click event for negation button
		this.negateButton.unbind('click').click( this.negate.bind(this) );
		// Change event for condition type selector
		this.selectElem.unbind('change').change( this.onSelectChange.bind(this) );
		// Force an initial, manual change event to retrieve the condition fields
		this.selectElem.trigger('change', [this.fieldData]);
	};

	/**
	 * Negates the condition.
	 */
	EddCmCondition.prototype.negate = function() {
		this.elem.toggleClass('negated');
		this.negateButton.toggleClass('button-red', this.isNegated());
	}

	/**
	 * Checks of the condition is negated.
	 */
	EddCmCondition.prototype.isNegated = function() {
		return this.elem.hasClass('negated');
	}
	
	/**
	 * Callback function called when the condition selector changes its value.
	 */
	EddCmCondition.prototype.onSelectChange = function( event, data ) {
		// Show loading
        this.fieldsContainer.html(this.loadingTemplate.clone(true, true));

		// Get the selected value
		var selected = this.selectElem.find('> option:selected').val();
		// Update the internal field
		this.condition = selected;
		// Prepare the AJAX  command
		var command = 'get_condition_fields[' + selected + ']';

		// Send the EDD CM AJAX command
		eddCmAjax(command, {}, function(response, status, jqXHR) {
			this.fieldsContainer.empty();
			// Populate the fields container with the returned HTML
			if ( response && response.fields ) {
				this.fieldsContainer.append($(response.fields));
				if (typeof data !== 'undefined') {
                    this.setFieldData(data);
                }
                this.fieldsContainer.find('.edd-select-chosen').chosen({
                    inherit_select_classes: true,
					placeholder_text_single: edd_vars.one_option,
					placeholder_text_multiple: edd_vars.one_or_more_option,
                });
				this.fieldsContainer.find('.edd-select-chosen').css( 'width', '300px' );
			}
		}.bind(this));
	};

	/**
	 * Gets the value of the fields.
	 */
	EddCmCondition.prototype.getFieldsData = function() {
		var data = {};
		this.fieldsContainer.find('.condition-field').each( function(e) {
			// Ensure element is a jQuery object
			var field = $(this);
			// Add to data object
			data[ field.attr('name') ] = field.val();
		});
		return this.fieldData = data;
	};

	EddCmCondition.prototype.setFieldData = function( data ) {
		this.fieldData = data;
		for (var name in data) {
			var value = data[name];
			this.fieldsContainer.find('[name="'+name+'"]').val(value);
		}
	};

	/**
	 * Overrides method to hide labels for message types.
	 */
	EddCmCondition.prototype.onConditionsChanged = function() {
		_super.prototype.onConditionsChanged.apply(this, []);
		this.labelsContainer.find('> p.if-message').hide();
	}

	/**
	 * Converts the condition into an std object.
	 */
	EddCmCondition.prototype.toObject = function() {
		var obj = _super.prototype.toObject.apply(this, []);
		return _.extend(obj, {
			type: this.condition,
			negation: this.isNegated(),
			data: this.getFieldsData(),
		});
	};

	return EddCmCondition;

}(EddCmConditional));
