var EddCmMessage = (function EddCmMessageClass(_super) {

	// Inheritance
	EddCmMessage.prototype = Object.create(_super.prototype);

	/**
	 * jQuery alias.
	 * @type {jQuery}
	 */
	var $ = jQuery;

	/**
	 * Class for a single message.
	 */
	function EddCmMessage( message, style, conditions, state ) {
		this.message = typeof message === 'undefined'? '' : message;
		this.style = typeof style === 'undefined'? '' : style;
		_super.apply(this, [conditions, state]);
	}

	/**
	 * Initializes the element.
	 */
	EddCmMessage.prototype.initElem = function() {
		// call super method
		_super.prototype.initElem.apply(this, []);
		// Add message type to conditional element
		this.elem.addClass('message');
		// Clone template
		var content = $('#edd-cm-message-template').clone(true, true).children();
		// Put cloned template into content element
		this.contentContainer.append(content);
		// Save pointer to the text field element
		this.textField = this.elem.find('input.message');
		// Set message to text field
		this.textField.val(this.message);
		// Save pointer to the style selector
		this.styleSelector = this.contentContainer.find('select.style');
		// Set the selected style
		this.styleSelector.val(this.style);
	};

	/**
	 * Initializes the events
	 */
	EddCmMessage.prototype.initEvents = function() {
		// call super method
		_super.prototype.initEvents.apply(this, []);
		// When the text changes its value, update the internal message
		this.textField.on('change input', this.onMessageChange.bind(this));
		// When the style selctor changes its value, update the interal style
		this.styleSelector.on('change', this.onStyleSelectorChange.bind(this));
	};

	/**
	 * Callback function for message text field change event.
	 */
	EddCmMessage.prototype.onMessageChange = function() {
		this.message = this.textField.val();
	};

	/**
	 * Callback function for style selector change event.
	 */
	EddCmMessage.prototype.onStyleSelectorChange = function() {
		this.style = this.styleSelector.find('> option:selected').val();
	};

	/**
	 * Overrides method to hide labels for condition types.
	 */
	EddCmMessage.prototype.onConditionsChanged = function() {
		_super.prototype.onConditionsChanged.apply(this, []);
		this.labelsContainer.find('> p.if-condition').hide();
	}

	/**
	 * Converts the message into an std object.
	 */
	EddCmMessage.prototype.toObject = function() {
		var obj = _super.prototype.toObject.apply(this, []);
		return _.extend(obj, {
			message: this.message,
			style: this.style,
		});
	};
	
	return EddCmMessage;

}(EddCmConditional));
