<?php

/**
 * Plugin Name: Easy Digital Downloads - Checkout Message
 * Plugin URI: https://wordpress.org/plugins/edd-checkout-message
 * Description: An Easy Digital Downloads extension to show messages upon checkout, based on configurable conditions. <strong>Requires PHP 5.3 or later</strong>.
 * Version: 1.0.7
 * Author: RebelCode
 * Author URI: https://www.rebelcode.com/
 * License: GPLv3
 * License URI: http://www.gnu.org/licenses/gpl-3.0.html
 * Text Domain: eddcm
 * Domain Path: /languages/
 */

/**
 * Copyright (C) 2015-2018 RebelCode Ltd.
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program.  If not, see <http://www.gnu.org/licenses/>.
 */

namespace EddCm;

// check if plugin is already loaded
if ( defined( 'EDDCM_MAIN_FILE' ) ) return;

// Directory Separator - if it does not exist
if ( ! defined( 'DS' ) ) define( 'DS', DIRECTORY_SEPARATOR );

// Define addon metadata constants
define ( 'EDD_CM_EXTENSION_NAME', 'Checkout Message' );

// Define main file and dir constants
define( 'EDDCM_MAIN_FILE', __FILE__ );
define( 'EDDCM_PLUGIN_BASENAME', plugin_basename(EDDCM_MAIN_FILE));
define( 'EDDCM_MAIN_DIR', \plugin_dir_path( EDDCM_MAIN_FILE ) );
define( 'EDDCM_MAIN_URL', \plugin_dir_url( EDDCM_MAIN_FILE ) );
define( 'EDDCM_INCLUDES_DIR', EDDCM_MAIN_DIR . '/includes/' );
// Parent Plugin Path
define( 'EDDCM_PARENT_PLUGIN', 'easy-digital-downloads' . DS . 'easy-digital-downloads.php' );
define( 'EDDCM_PARENT_PLUGIN_CLASS', 'Easy_Digital_Downloads' );
define( 'EDDCM_PARENT_PLUGIN_MIN_VERSION', '2.6.15' );

// Load the autoloader - oh the puns!
require implode(DIRECTORY_SEPARATOR, array(EDDCM_MAIN_DIR, 'vendor', 'autoload.php'));

/**
 * Returns the EddCm singleton instance.
 *
 * @return EddCm\Main
 */
function Main() {
	return Main::instance();
}

try {
	// Init singleton and run
	Main()->run();
} catch ( Exceptions\GeneralException $e ) {
	$e->onThrown();
}

/**
 * Checks for EDD core at minimum required version when all plugins are loaded.
 */
add_action('plugins_loaded', function() {
    if (!\class_exists(EDDCM_PARENT_PLUGIN_CLASS)) {
        Main()->deactivate(
            __('The EDD Checkout Message plugin has been deactivated. The Easy Digital Downloads plugin must be installed and activated.', 'eddcm')
        );
    } else if (version_compare(EDD_VERSION, EDDCM_PARENT_PLUGIN_MIN_VERSION, '<')) {
        Main()->deactivate(
            \sprintf(
                '%s <strong><code>%s</code></strong>',
                __('The EDD Checkout Message plugin has been deactivated. Minimum Easy Digital Downloads version required:', 'eddcm'),
                EDDCM_PARENT_PLUGIN_MIN_VERSION
            )
        );
    }
});
