<?php

namespace EddCm\Controllers;

use EddCm\FileLoader;
use EddCm\Lib\Actions\MessageAction;
use EddCm\Main;

/**
 * Messages controller class.
 */
class MessagesController extends AbstractController {

	/**
	 * The classname of the base style class.
	 */
	const BASE_STYLE_CLASSNAME = 'EddCm\Lib\Base\AbstractStyle';

	/**
	 * The messages.
	 * 
	 * @var array
	 */
	protected $_messages;

	/**
	 * The message styles
	 * 
	 * @var array
	 */
	protected $_styles;

	/**
	 * Constructor.
	 */
	public function __construct() {
		parent::__construct('Messages');
	}

	/**
	 * Initialization method called on hook:action:edd_cm_controllers_loaded
	 */
	public function init() {
		$main = Main::getInstance();
		// Hooks
		$main->getHookLoader()->add_action('edd_checkout_cart_bottom', $this, 'execMessages');
		$main->getHookLoader()->add_action('wp_enqueue_scripts', $this, 'enqueueStyles');
		// Prepare the styles array
		$this->_styles = array();
		// Get the saved messages from the settings
		$saved = $main->getController('Settings')->get();
		// Prepare the messages array
		$this->_messages = array();
		foreach ( $saved as $key => $messageArray ) {
			$this->_messages[] = MessageAction::fromArray( $messageArray );
		}
	}

	/**
	 * Gets the messages.
	 * 
	 * @return array An array of MessageAction instances.
	 */
	public function getMessages() {
		return $this->_messages;
	}

	/**
	 * Registers a style.
	 * 
	 * @param string $style The style class name.
	 */
	public function registerStyle( $style ) {
		if ( is_subclass_of( $style, self::BASE_STYLE_CLASSNAME ) )
			$this->_styles[ $style ] = $style::getName();
		return $this;
	}

	/**
	 * Gets the messages.
	 * 
	 * @return array An array of MessageAction instances.
	 */
	public function getStyles() {
		return $this->_styles;
	}

	/**
	 * Executes all messages.
	 */
	public function execMessages() {
		// Iterate all messages
		foreach ($this->_messages as $message) {
			// Execute conditional message execution method
			echo $message->exec();
		}
	}

	/**
	 * Enqueues styles.
	 */
	public function enqueueStyles() {
		wp_register_style(
            'edd-cm-cart-css',
            FileLoader::uri(Main::ASSETS_PATH, 'css', 'edd-cm-cart.css'),
            array(),
            Main::getInstance()->getData('Version')
        );
		wp_enqueue_style( 'edd-cm-cart-css' );
	}

}

// Create a new controller instance
new MessagesController();
