<?php

namespace EddCm;

/**
 * File loader class.
 */
abstract class FileLoader {

	/**
	 * Generates a path string for a file or directory within the plugin's file structure.
	 *
	 * @param  array $args Any number of arguments
	 * @return string
	 */
	public static function path(/* $arg0, $arg1, ... */) {
		return EDDCM_MAIN_DIR . self::arrayToPath( func_get_args() );
	}

	/**
	 * Generates a URI string for a file or directory within the plugin's file structure.
	 *
	 * @param  array $args Any number of arguments
	 * @return string
	 */
	public static function uri(/* arg0, $arg1, ... */) {
		return EDDCM_MAIN_URL . self::arrayToPath( func_get_args() );
	}

	/**
	 * Same as arrayToPath, but accepts a variable number of params.
	 * 
	 * @return string The generated path string.
	 */
	public static function paramsToPath(/* $arg0, $arg1, ... */) {
		return arrayToPath( func_get_args() );
	}

	/**
	 * Generates a path string using the given array of components.
	 * 
	 * @param  array $arr The array to merge into a path string.
	 * @return string     The generated path string.
	 */
	public static function arrayToPath( $arr ) {
		return join( '/', $arr );
	}

    /**
     * Loads all files in a given directory.
     *
     * @param string $directory The absolute directory path.
     * @param string $extension [optional] The file extension.
     */
    public static function loadDirectory($directory, $extension = 'php') {
		$entries = glob(sprintf('%s%s*.%s', $directory, DS, $extension));
		if (!is_array($entries)) {
            return;
        }
		foreach ($entries as $filename) {
			include_once $filename;
		}
    }

}
