<?php

namespace EddCm\Lib\Base;

/**
 * Abstract class for a conditional object.
 */
abstract class AbstractConditionalObject implements Conditional {

	const EVAL_COMP_OR = true;
	const EVAL_COMP_AND = false;

	/**
	 * The subconditions.
	 * 
	 * @var array
	 */
	protected $_conditions;

	/**
	 * The evaluation comparator mode.
	 * 
	 * @var boolean
	 */
	protected $_evalComp;

	/**
	 * Constructor.
	 */
	public function __construct($conditions = array()) {
		$this->_conditions = $conditions;
		$this->_evalComp = self::EVAL_COMP_OR;
	}

	/**
	 * Sets the evaluation comparator.
	 * 
	 * @param boolean $evalComp Either AbstractConditionalObject::EVAL_COMP_OR or AbstractConditionalObject::EVAL_COMP_AND.
	 */
	public function setEvalComparator($evalComp) {
		$this->_evalComp = $evalComp;
	}

	/**
	 * Gets the conditions.
	 * 
	 * @return array
	 */
	public function getConditions() {
		return $this->_conditions;
	}

	/**
	 * Evaluates the conditions.
	 * 
	 * @return boolean True if at least one of the conditions is satisfied, false if none are satisfied.
	 */
	public function evaluateConditions() {
		if ( count($this->_conditions) == 0 ) return true;
		foreach ($this->_conditions as $condition)
			if ($condition->evaluate() === $this->_evalComp)
				return $this->_evalComp;
		return !$this->_evalComp;
	}

}
