<?php

namespace EddCm\Lib\Base;
use EddCm\Main;

/**
 * Abstract class for an operator.
 */
abstract class AbstractOperator implements Operator {

	/**
	 * The operands.
	 * 
	 * @var array
	 */
	protected $_operands;

	/**
	 * Constructs a new instance.
	 * 
	 * @param array $operands The operands.
	 */
	public function __construct($operands = array()) {
		$this->_operands = $operands;
	}

	/**
	 * Registers the operator to the OperatorsController.
	 * Should be called on hook:action:edd_cm_controllers_loaded
	 */
	public static function register() {
		Main::getInstance()->getController('Operators')->registerOperatorType( get_called_class() );
	}

	/**
	 * Evaluates using this operator and the instance operands.
	 * 
	 * @return mixed The resulting value of the evaluation.
	 */
	public function evaluate() {
		return $this->_evaluate( $this->_operands );
	}

	/**
	 * Internal evaluate method for overriding.
	 * 
	 * @param array $args The operands to use for evaluation using this operator.
	 */
	abstract protected function _evaluate($operands = array());
	
	/**
	 * Gets the operator's textual or symbol representation.
	 * 
	 * @return string
	 */
	public static function getRepresentation() {
		return '?';
	}

}
