<?php

namespace EddCm\Lib\Base;
use EddCm\Main;

/**
 * Abstract style class.
 */
abstract class AbstractStyle {

	/**
	 * The view name for this style.
	 * 
	 * @var string
	 */
	protected $_view;

	/**
	 * Constructor.
	 */
	public function __construct() {
		$this->_view = 'MessageView';
	}

	/**
	 * Registers the style.
	 */
	public static function register() {
		Main::getInstance()->getController('Messages')->registerStyle( get_called_class() );
	}

	/**
	 * Generates the viewbag for the rendering of the view.
	 * 
	 * @param  string $text The message text.
	 * @return array        The viewbag array.
	 */
	protected function _generateViewbag( $text ) {
		return array_merge(
			array( 'text'	=>	$text ),
			$this->_getViewbag()
		);
	}

	/**
	 * Gets the viewbag. This is meant to be overriden by subclasses.
	 * 
	 * @return array
	 */
	protected function _getViewbag() {
		return array();
	}

	/**
	 * Renders the style using the given message text.
	 * 
	 * @param  string $text The message text.
	 * @return string       The rendered view.
	 */
	public function renderView( $text = '' ) {
		return Main::renderView( $this->_view, $this->_generateViewbag( $text ) );
	}

	/**
	 * Gets the name of the style, shown on the settings page.
	 *
	 * @return string
	 */
	public static function getName() {
		return '...';
	}

}