<?php

namespace EddCm\Lib\Conditions;
use \EddCm\Main;

/**
 * Condition for comparing the total cart final price.
 */
class CartTotalNumItemsCondition extends CartTotalPriceCondition {

	/**
	 * Field type constant, for specifying what fields are rendered for this condition in the settings UI.
	 */
	const FIELD_TYPE = 'PriceCompareFields';

	/**
	 * Constructs a new instance.
	 * 
	 * @param array $conditions The subconditions. Default: array()
	 */
	public function __construct( $conditions = array() ) {
		parent::__construct( $conditions );
	}

	/**
	 * Evaluates the condition to either true or false.
	 * 
	 * @return boolean
	 */
	protected function _evaluate() {
		// Get the operator class anme
		$operatorClassname = $this->_operator;
		// If the class does not exist, stop
		if ( ! class_exists( $operatorClassname ) ) return false;
		// Prepare the operands
		$operands = array(
			edd_get_cart_quantity(),
			$this->_value
		);
		// Create the operator instance
		$operator = new $operatorClassname( $operands );
		// Return the operator's evaluation
		return $operator->evaluate();
	}

	/**
	 * Returns the viewbag for the fields view.
	 * 
	 * @return array
	 */
	protected static function _getViewbag() {
		$viewbag = parent::_getViewbag();
		$viewbag['valueStep'] = 1;
		return $viewbag;
	}

	/**
	 * Gets the description, required for showing this condition in the settings UI.
	 *
	 * @return string
	 */
	public static function getDescription() {
		return __( 'The total number of items in the cart is ...', Main::TEXT_DOMAIN );
	}

}

// Register the Condition type
add_action( 'edd_cm_controllers_loaded', __NAMESPACE__ . '\CartTotalNumItemsCondition::register' );
