<?php

namespace EddCm\Lib\Conditions;
use \EddCm\Main;
use \EddCm\Lib\Base\AbstractCondition;

/**
 * Condition for comparing the total cart final price.
 */
class CartTotalPriceCondition extends AbstractCondition {

	/**
	 * Field type constant, for specifying what fields are rendered for this condition in the settings UI.
	 */
	const FIELD_TYPE = 'PriceCompareFields';

	/**
	 * The comparing operator.
	 * 
	 * @var string
	 */
	protected $_operator;

	/**
	 * The comparing value.
	 * 
	 * @var float
	 */
	protected $_value;

	/**
	 * Constructs a new instance.
	 * 
	 * @param array $conditions The subconditions. Default: array()
	 */
	public function __construct( $conditions = array() ) {
		parent::__construct( $conditions );
		$this->_operator = null;
		$this->_value = 0;
	}

	/**
	 * Gets the comparing operator.
	 *
	 * @return string
	 */
	public function getOperator() {
		return $this->_operator;
	}

	/**
	 * Sets the comparing operator.
	 *
	 * @param string $_operator The operator classname.
	 */
	protected function setOperator( $operator ) {
		$this->_operator = $operator;
	}

	/**
	 * Gets the comparing value.
	 *
	 * @return float
	 */
	public function getValue() {
		return $this->_value;
	}

	/**
	 * Sets the comparing value.
	 *
	 * @param float $_value The value
	 */
	protected function setValue( $value ) {
		$this->_value = $value;
	}

	/**
	 * Evaluates the condition to either true or false.
	 * 
	 * @return boolean
	 */
	protected function _evaluate() {
		// Get the operator class anme
		$operatorClassname = $this->_operator;
		// If the class does not exist, stop
		if ( ! class_exists( $operatorClassname ) ) return false;
		// Prepare the operands
		$operands = array(
			edd_get_cart_total(),
			$this->_value
		);
		// Create the operator instance
		$operator = new $operatorClassname( $operands );
		// Return the operator's evaluation
		return $operator->evaluate();
	}

	/**
	 * Returns the viewbag for the fields view.
	 * 
	 * @return array
	 */
	protected static function _getViewbag() {
		return array(
			'valueMin'	=>	'0',
			'valueMax'	=>	'',
			'valueStep'	=>	0.01,
		);
	}

	/**
	 * Gets the description, required for showing this condition in the settings UI.
	 *
	 * @return string
	 */
	public static function getDescription() {
		return __( "The cart's total price is ...", Main::TEXT_DOMAIN );
	}

}

// Register the Condition type
add_action( 'edd_cm_controllers_loaded', __NAMESPACE__ . '\CartTotalPriceCondition::register' );
