<?php

namespace EddCm\Lib\Conditions;
use \EddCm\Main;
use \EddCm\Lib\Base\AbstractCondition;

/**
 * Condition for an item being present in the cart.
 */
class ItemInCartCondition extends AbstractCondition {

	/**
	 * Field type constant, for specifying what fields are rendered for this condition in the settings UI.
	 */
	const FIELD_TYPE = 'EddDownloadSelector';
	
	/**
	 * The item ID.
	 * 
	 * @var integer
	 */
	protected $_item;

	/**
	 * Constructs a new instance.
	 * 
	 * @param mixed $item       The item ID as an integer or numeric string.
	 * @param array $conditions The subconditions. Default: array()
	 */
	public function __construct( $conditions = array() ) {
		parent::__construct( $conditions );
		$this->_item = 0;
	}

	/**
	 * Sets the item ID.
	 * 
	 * @param integer $item The item ID.
	 */
	public function setItem( $item ) {
		$this->_item = intval( $item );
	}

	/**
	 * Gets the item ID.
	 * 
	 * @return integer
	 */
	public function getItem() {
		return $this->_item;
	}

	/**
	 * Evaluates the condition to either true or false.
	 * 
	 * @return boolean
	 */
	protected function _evaluate() {
		return edd_item_in_cart( $this->_item );
	}

	/**
	 * Gets the description, required for showing this condition in the settings UI.
	 *
	 * @return string
	 */
	public static function getDescription() {
		return __( "A particular item is present in the user's cart.", Main::TEXT_DOMAIN );
	}

}

// Register the Condition type
add_action( 'edd_cm_controllers_loaded', __NAMESPACE__ . '\ItemInCartCondition::register' );
