<?php

namespace EddCm\Operators;
use EddCm\Lib\Base\AbstractOperator;

/**
 * A less than or equals operator. Performs "less than or is equal to" arithmetic comparison on two operands.
 */
class LessThanEqualsOperator extends AbstractOperator {

	/**
	 * Internal, overidden, evaluation method.
	 * 
	 * @param  array   $operands The operands to use for evaluation.
	 * @return boolean           True if the first operand is less than or equal to the second, false otherwise.
	 */
	protected function _evaluate( $operands = array() ) {
		if ( count( $operands ) !== 2 ) return NULL;
		list( $operand1, $operand2 ) = $operands;
		return $operand1 <= $operand2;
	}

	/**
	 * Gets the operator's textual or symbol representation.
	 * 
	 * @return string
	 */
	public static function getRepresentation() {
		return '<=';
	}

}

// Register the Operator type
add_action( 'edd_cm_controllers_loaded', 'EddCm\Operators\LessThanEqualsOperator::register' );